@@ -14,13 +14,14 @@
 wk_identity <- function(handleable, ...) {
   result <- wk_handle(handleable, wk_identity_filter(wk_writer(handleable)), ...)
   result <- wk_restore(handleable, result, ...)
-  wk_set_crs(result, wk_crs(handleable))
+  result <- wk_set_crs(result, wk_crs(handleable))
+  wk_set_geodesic(result, wk_is_geodesic(handleable))
 }
 
 #' @rdname wk_identity
 #' @export
 wk_identity_filter <- function(handler) {
-  new_wk_handler(.Call("wk_c_identity_filter_new", as_wk_handler(handler)))
+  new_wk_handler(.Call("wk_c_identity_filter_new", as_wk_handler(handler)), "wk_identity_filter")
 }
 
 #' @rdname wk_identity
